polar2grid.readers.agri\_fy4b\_l1 module
========================================

.. automodule:: polar2grid.readers.agri_fy4b_l1
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
